<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.beans.serializer
 */
/**
 * @file BeanSerializer.php
 * @brief serialize bean.
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: BeanSerializer.php 48 2007-09-20 07:21:07Z ishitoya $
 */

/**
 * @interface Ficus_BeanSerializer
 */
interface Ficus_BeanSerializer{
    /**
     * serialize bean
     * @param $bean Ficus_Bean target bean
     * @return string serialized data
     */
    public function serialize($bean, $arguments = null);
}
?>
